@@ -22,6 +22,7 @@ except ImportError:
     from pylibrabbitmq import ChannelError, ConnectionError  # noqa
 
 from kombu.exceptions import StdChannelError
+from kombu.utils.amq_manager import get_manager
 
 from . import base
 
@@ -35,10 +36,10 @@ class Message(base.Message):
                 body=body,
                 delivery_info=info,
                 properties=props,
-                delivery_tag=info["delivery_tag"],
-                content_type=props["content_type"],
-                content_encoding=props["content_encoding"],
-                headers=props.get("headers"))
+                delivery_tag=info['delivery_tag'],
+                content_type=props['content_type'],
+                content_encoding=props['content_encoding'],
+                headers=props.get('headers'))
 
 
 class Channel(amqp.Channel, base.StdChannel):
@@ -49,10 +50,10 @@ class Channel(amqp.Channel, base.StdChannel):
                 properties=None):
         """Encapsulate data into a AMQP message."""
         properties = properties if properties is not None else {}
-        properties.update({"content_type": content_type,
-                           "content_encoding": content_encoding,
-                           "headers": headers,
-                           "priority": priority})
+        properties.update({'content_type': content_type,
+                           'content_encoding': content_encoding,
+                           'headers': headers,
+                           'priority': priority})
         return body, properties
 
 
@@ -70,12 +71,17 @@ class Transport(base.Transport):
                          IOError,
                          OSError)
     channel_errors = (StdChannelError, ChannelError, )
+    driver_type = 'amqp'
+    driver_name = 'librabbitmq'
 
     nb_keep_draining = True
 
     def __init__(self, client, **kwargs):
         self.client = client
-        self.default_port = kwargs.get("default_port") or self.default_port
+        self.default_port = kwargs.get('default_port') or self.default_port
+
+    def driver_version(self):
+        return amqp.__version__
 
     def create_channel(self, connection):
         return connection.channel()
@@ -114,8 +120,11 @@ class Transport(base.Transport):
     def eventmap(self, connection):
         return {connection.fileno(): self.client.drain_nowait}
 
+    def get_manager(self, *args, **kwargs):
+        return get_manager(self.client, *args, **kwargs)
+
     @property
     def default_connection_params(self):
-        return {"userid": "guest", "password": "guest",
-                "port": self.default_port,
-                "hostname": "localhost", "login_method": "AMQPLAIN"}
+        return {'userid': 'guest', 'password': 'guest',
+                'port': self.default_port,
+                'hostname': 'localhost', 'login_method': 'AMQPLAIN'}
